# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog],
and this project adheres to [Semantic Versioning].

## [1.0.4] - 2025-06-15

### Added
- `padrelay-keymapper` CLI for creating controller mapping files

## [1.0.3] - 2025-06-14

### Fixed
- Synced GitHub release and PyPI version numbers to avoid mismatch
- Ensured correct artifacts attached to GitHub Releases

## [1.0.2] - 2025-06-14

### Fixed
- Corrected `version` field in `pyproject.toml` to match intended release

## [1.0.1] - 2025-06-14

### Added
- CI: GitHub Actions workflow for testing with pytest (`python-tests.yml`)
- CI: GitHub Actions workflow for building and publishing releases on tag push (`release.yml`)

## [1.0.0] - 2025-06-14

- initial release

<!-- Links -->
[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html

<!-- Versions -->
[1.0.4]: https://github.com/ssh-den/PadRelay/releases/tag/v1.0.4
[1.0.3]: https://github.com/ssh-den/PadRelay/releases/tag/v1.0.3
[1.0.2]: https://github.com/ssh-den/PadRelay/releases/tag/v1.0.2
[1.0.1]: https://github.com/ssh-den/PadRelay/releases/tag/v1.0.1
[1.0.0]: https://github.com/ssh-den/PadRelay/releases/tag/v1.0.0
